@@ -526,6 +526,9 @@ impl<A> SignalVec for Always<A> {
     }
 }
 
+/// Converts a `Vec<A>` into a `SignalVec<Item = A>`
+///
+/// This has no performance cost.
 #[inline]
 pub fn always<A>(values: Vec<A>) -> Always<A> {
     Always {
@@ -534,6 +537,35 @@ pub fn always<A>(values: Vec<A>) -> Always<A> {
 }
 
 
+#[pin_project(project = StreamSignalVecProj)]
+#[derive(Debug)]
+#[must_use = "SignalVecs do nothing unless polled"]
+pub struct StreamSignalVec<S> {
+    #[pin]
+    stream: S,
+}
+
+impl<S> SignalVec for StreamSignalVec<S> where S: Stream {
+    type Item = S::Item;
+
+    fn poll_vec_change(self: Pin<&mut Self>, cx: &mut Context) -> Poll<Option<VecDiff<Self::Item>>> {
+        let StreamSignalVecProj { stream } = self.project();
+
+        stream.poll_next(cx).map(|some| some.map(|value| VecDiff::Push { value }))
+    }
+}
+
+/// Converts a `Stream<Item = A>` into a `SignalVec<Item = A>`
+///
+/// The values are always pushed to the end of the SignalVec. This has no performance cost.
+#[inline]
+pub fn from_stream<S>(stream: S) -> StreamSignalVec<S> {
+    StreamSignalVec {
+        stream,
+    }
+}
+
+
 #[pin_project]
 #[derive(Debug)]
 #[must_use = "Futures do nothing unless polled"]
@@ -2134,7 +2166,6 @@ mod mutable_vec {
     use std::task::{Poll, Context};
     use futures_channel::mpsc;
     use futures_util::stream::StreamExt;
-    use serde::{Serialize, Deserialize, Serializer, Deserializer};
 
 
     // TODO replace with std::slice::range after it stabilizes
@@ -2759,16 +2790,18 @@ mod mutable_vec {
         }
     }
 
-    impl<T> Serialize for MutableVec<T> where T: Serialize {
+    #[cfg(feature = "serde")]
+    impl<T> serde::Serialize for MutableVec<T> where T: serde::Serialize {
         #[inline]
-        fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where S: Serializer {
+        fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where S: serde::Serializer {
             self.0.read().unwrap().values.serialize(serializer)
         }
     }
 
-    impl<'de, T> Deserialize<'de> for MutableVec<T> where T: Deserialize<'de> {
+    #[cfg(feature = "serde")]
+    impl<'de, T> serde::Deserialize<'de> for MutableVec<T> where T: serde::Deserialize<'de> {
         #[inline]
-        fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where D: Deserializer<'de> {
+        fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where D: serde::Deserializer<'de> {
             <Vec<T>>::deserialize(deserializer).map(MutableVec::new_with_values)
         }
     }
